{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for TypeScript.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/typescript.xml and 'make bootstrap'.
module Skylighting.Syntax.Typescript (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for TypeScript.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtypescript.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypescript\NUL\NUL\NUL\NUL\NUL\NUL\NUL9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltInClasses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltInClasses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMath\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindMemberObjectMath\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFindMemberObjectNumber\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPromise\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectPromise\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJSON\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindMemberObjectJSON\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconsole\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectConsole\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprocess\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectProcess\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindMemberObjectDOM\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBuiltInConstants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBuiltInConstants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL:\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANConditionalExpressionEnd\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL?\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL!FindConditionalExpressionBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCNormal-ParametersOverridden\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANConditionalExpressionEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANConditionalExpressionEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ;,}])\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\=(?!>)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX```\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX~~~\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2</script\\s*(?:>|$)\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ConditionalExpressionRoundBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ConditionalExpressionRoundBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL!FindConditionalExpressionBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"ConditionalExpressionSquareBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"ConditionalExpressionSquareBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL]\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL!FindConditionalExpressionBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rControlExport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rControlExport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX{;\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH?.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH!.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\205[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*(?=\\s*(?:<(?:\\{(?:[^\\{\\}]|\\{[^\\{\\}]*\\})*\\}|\\((?:[^\\(\\)]|\\([^\\(\\)]*\\))*\\)|\\[(?:[^\\[\\]]|\\[[^\\[\\]]*\\])*\\]|'(?:\\\\.|[^'])*'|\"(?:\\\\.|[^\"])*\"|`(?:\\\\.|[^`])*`|[^<>]|<.*>)*>)?\\()\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL([a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*\\s*`\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL)#(?=[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL3[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*(?=\\s*[\\?!]?\\.)\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDefaultTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDefaultTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbigint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnever\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tundefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunknown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENoRegExpSameLine\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aasserts\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENoRegExpSameLine\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENoRegExpSameLine\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\\b(?:string|number|bigint|boolean|symbol|any|void|never|unknown|undefined|null|object)(?=\\})\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX:?\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!FindConditionalExpressionBrackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL!FindConditionalExpressionBrackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ConditionalExpressionRoundBracket\NUL[\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"ConditionalExpressionSquareBracket\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectConsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectConsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectConsole\SOH?.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectConsole\SOH!.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectConsole\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindMemberObjectDOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindMemberObjectDOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMemberObjectDOM\SOH?.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMemberObjectDOM\SOH!.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMemberObjectDOM\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindMemberObjectJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindMemberObjectJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectJSON\SOH?.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectJSON\SOH!.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectJSON\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindMemberObjectMath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindMemberObjectMath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectMath\SOH?.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectMath\SOH!.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectMath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFindMemberObjectNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFindMemberObjectNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MemberObjectNumber\SOH?.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MemberObjectNumber\SOH!.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MemberObjectNumber\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectProcess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectProcess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectProcess\SOH?.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectProcess\SOH!.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectProcess\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectPromise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFindMemberObjectPromise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectPromise\SOH?.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectPromise\SOH!.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectPromise\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindNumbers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindNumbers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\\b0[xX][\\da-fA-F][\\da-fA-F_]*(?=n?(?:[^\\w]|$))\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\\b0[bB][01][01_]*(?=n?(?:[^\\w]|$))\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULO(?:\\b\\d[\\d_]*\\.?|(?:\\b\\d[\\d_]*)?\\.\\d[\\d_]*)[eE][\\+\\-]?\\d[\\d_]*(?=n?(?:[^\\w]|$))\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL9(?:\\.\\d[\\d_]*|\\b\\d[\\d_]*\\.(?:\\d[\\d_]*)?)(?=n?(?:[^\\w]|$))\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL%\\b0[oO]?[0-7][0-7_]*(?=n?(?:[^\\w]|$))\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\b\\d[\\d_]*(?=n?(?:[^\\w]|$))\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL`\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTemplate\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPointMemberObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT?...\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT!...\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX...\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPopLineEndContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPopLineEndContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\DC1\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(<>\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FunctionDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FunctionDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\205[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*(?=\\s*(?:<(?:\\{(?:[^\\{\\}]|\\{[^\\{\\}]*\\})*\\}|\\((?:[^\\(\\)]|\\([^\\(\\)]*\\))*\\)|\\[(?:[^\\[\\]]|\\[[^\\[\\]]*\\])*\\]|'(?:\\\\.|[^'])*'|\"(?:\\\\.|[^\"])*\"|`(?:\\\\.|[^`])*`|[^<>]|<.*>)*>)?\\()\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKImport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKImport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEImportRequireKey\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmeta\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b{}()[];,\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rImportRequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rImportRequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindNumbers\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEImportRequireKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEImportRequireKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\s*require\\s*(?=\\()\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rImportRequire\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMemberObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMemberObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectConsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectConsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMemberObjectDOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMemberObjectDOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindMemberObjectDOM\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FindMemberObjectDOM\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectMath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMemberObjectMath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MemberObjectNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MemberObjectNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectProcess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectProcess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectPromise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MemberObjectPromise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DefaultMemberObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNewTarget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNewTarget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.?!\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtarget\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENoRegExpSameLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENoRegExpSameLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNormal Pt1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*(?=\\s*[\\?!]?:)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNormal Pt2\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNormal Pt1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNormal Pt1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX...\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindNumbers\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\\babstract(?=\\s+(?:class|interface)\\b)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\\bnew(?=\\s*[\\?!]?\\.\\s*target\\b)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNewTarget\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\bnew(?=[\\?!]?\\.)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMemberObject\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\DC3\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\bdefault(?=\\s*[\\?!]?:)\SOH\DC3\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNormal Pt2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNormal Pt2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITypeDeclaration\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FunctionDeclaration\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babstract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\targuments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconstructor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULu\\b(?:Partial|Readonly|Record|Pick|Omit|Exclude|Extract|NonNullable|ReturnType|InstanceType|Required|ThisType)(?=\\s*<)\SOH\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltInClasses\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBuiltInConstants\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL3[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*(?=\\s*[\\?!]?\\.)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMemberObject\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMemberObject\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\bas(?=\\s)\SOH\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTypes\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKImport\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\bexport\\s+type\\b\SOH\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rControlExport\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aawaited\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkeyof\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\207([a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*)(?=\\s*(?:<(?:\\{(?:[^\\{\\}]|\\{[^\\{\\}]*\\})*\\}|\\((?:[^\\(\\)]|\\([^\\(\\)]*\\))*\\)|\\[(?:[^\\[\\]]|\\[[^\\[\\]]*\\])*\\]|'(?:\\\\.|[^'])*'|\"(?:\\\\.|[^\"])*\"|`(?:\\\\.|[^`])*`|[^<>]|<.*>)*>)?\\()\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL,[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*(?=\\s*`)\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SOH??\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\153\\?(?=\\s*(?:(?:[^/\"'`\\s\\?:\\.;,\\=\\}\\]\\)]|\"(?:[^\"]|\\\\.)*\"|'(?:[^']|\\\\.)*'|`(?:[^`]|\\\\.)`|/\\*.*\\*/|/(?:[^/\\\\\\[]|\\\\.|\\[(?:[^\\]\\\\]|\\\\.)+\\])+/)(?:[^/\"'`]|\"(?:[^\"]|\\\\.)*\"|'(?:[^']|\\\\.)*'|`(?:[^`]|\\\\.)`|/\\*.*\\*/|/(?:[^/\\\\\\[]|\\\\.|\\[(?:[^\\]\\\\]|\\\\.)+\\])+/)*)?[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*\\s*(?:/\\*.*\\*/\\s*)*:|(?:&&|\\|\\||\\s*(?:/\\*.*\\*/\\s*)*[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*)?\\s*(?:$|//|(?:/\\*.*\\*/\\s*)+(?:$|//)))\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\NUL:\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTypes\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL:<(?=(?:[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*|[\\[\\{\\(<]).*>)\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesAngleBracket\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKJSBase\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCNormal-ParametersOverridden\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCNormal-ParametersOverridden\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNormal Pt1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNormal Pt2\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*(?=\\s*[\\?!]?:)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\t\n !\"%&'()*+,-./:;<=>?[\\]^`{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL):(?=\\s*(?:$|//|(?:/\\*.*\\*/\\s*)+(?:$|//)))\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTypesNewLine\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH#!\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstitution\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstitution\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEscape\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH${\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstitution\NUL`\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RegExpAfterString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITypeDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITypeDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK;,{})]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesFindBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDefaultTypes\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPopLineEndContext\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTypesCommon\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesAngleBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesAngleBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL>\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TypesAngleBracketEnd\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPopLineEndContext\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesFindBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDefaultTypes\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TypesAngleBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TypesAngleBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT})];\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTypesCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTypesCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTypesEnd\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL-[\\|&](?=\\s*(?:$|//|(?:/\\*.*\\*/\\s*)+(?:$|//)))\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTypesNewLine\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesFindBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDefaultTypes\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCNormal-ParametersOverridden\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesCurlyBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesCurlyBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesFindBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDefaultTypes\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTypesEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTypesEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ;,}])\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\=(?!>)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH//\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesFindBrackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesFindBrackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2TypesSquareBracket\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesCurlyBracket\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesRoundBracket\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTypesNewLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTypesNewLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTypesCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesRoundBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesRoundBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FixPopLineEndContext\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesFindBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDefaultTypes\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2TypesSquareBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2TypesSquareBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TypesFindBrackets\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDefaultTypes\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%Nibaldo Gonz\195\161lez (nibgonz@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.ts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang"
